package com.nec.connexive.thingpark.token.verifier;

import java.lang.management.ManagementFactory;
import java.util.Map;
import java.util.concurrent.ConcurrentHashMap;

public class SystemPropertyWrapper {

    private static Map<String, String> prop = new ConcurrentHashMap<>(ManagementFactory.getRuntimeMXBean().getSystemProperties());

    private SystemPropertyWrapper() {
    }

    /**
     * システムプロパティを管理するMap内にキー名が含まれているか確認する.<br>
     * <br>
     *
     * @param key キー名
     * @return true or false
     */
    public static boolean containsKey(final String key) {
        if (key == null || key.isEmpty()) {
            return false;
        } else {
            return prop.containsKey(key);
        }
    }

    /**
     * システムプロパティを管理するMap内から値を取得する.<br>
     * <br>
     *
     * @param key キー名
     * @return システムプロパティ値
     */
    public static String getprop(final String key) {
        if (key == null || key.isEmpty()) {
            return "";
        } else {
            String value = prop.get(key);
            return value == null ? "" : value;
        }
    }

    /**
     * システムプロパティを管理するMap内に値を設定する.<br>
     * <br>
     *
     * @param key キー名
     * @param value システムプロパティ値
     */
    public static void setprop(final String key, final String value) {
        if (key != null && !key.isEmpty() && value != null && !value.isEmpty()) {
            prop.put(key, value);
        }
    }

    /**
     * システムプロパティを管理するMap内から値を削除する.<br>
     * <br>
     *
     * @param key キー名
     */
    public static void removeprop(final String key) {
        if (key != null && !key.isEmpty()) {
            prop.remove(key);
        }
    }

}
